
#include "../link-grammar/link-features.h"

LINK_BEGIN_DECLS
void viterbi_parse(const char * sentence, Dictionary dict);
LINK_END_DECLS

